Index: /trunk/src/VBox/HostDrivers/Support/win/SUPDrvA-win.asm
===================================================================
--- /trunk/src/VBox/HostDrivers/Support/win/SUPDrvA-win.asm	(revision 51957)
+++ /trunk/src/VBox/HostDrivers/Support/win/SUPDrvA-win.asm	(revision 51958)
@@ -51,7 +51,7 @@
 ;
 ; Faking up ZwQueryVirtualMemory on XP and W2K3 where it's not exported.
 ; Using ZwReadFile as a helper as it has the name number of parameters.
 ;
-extern  IMPNAME(ZwReadFile@24)
+extern  IMPNAME(ZwOpenFile@24)
 
 BEGINPROC supdrvNtQueryVirtualMemory_Xxx
@@ -79,5 +79,5 @@
 
 supdrvNtQueryVirtualMemory_Jump:
-        mov     edx, IMP2(ZwReadFile@24)
+        mov     edx, IMP2(ZwOpenFile@24)
         lea     edx, [edx + 5]
         jmp     edx
@@ -51,7 +51,7 @@
 ;
 ; Faking up ZwQueryVirtualMemory on XP and W2K3 where it's not exported.
-; Using ZwReadFile as a helper as it has the name number of parameters.
+; Using ZwOpenFile as a helper as it has the name number of parameters.
 ;
